@@ -179,6 +179,8 @@ async function activate(
                     console.debug("kernel_name", kernel_name)
                     const resolution_engine: string = _.get(jsonObject, "resolution_engine")
                     console.debug("resolution_engine", resolution_engine)
+                    const thoth_analysis_id: string = _.get(jsonObject, "thoth_analysis_id")
+                    console.debug("thoth_analysis_id", thoth_analysis_id)
 
                     let notebook_metadata = notebook.model.metadata
                     notebook_metadata.set('dependency_resolution_engine', resolution_engine)
@@ -187,6 +189,7 @@ async function activate(
                       retrieve_config_file(kernel_name).then(thoth_config  => {
                           notebook_metadata.set('thoth_config', JSON.stringify(thoth_config))
                       })
+                      notebook_metadata.set('thoth_analysis_id', thoth_analysis_id)
                     }
 
                     get_dependencies(kernel_name).then(value => {
@@ -256,25 +259,28 @@ async function activate(
             const cell_response: {} = cell_.toJSON()
             const outputs = _.get(cell_response, "outputs")
 
-            if ( _.size(outputs) > 0  && _.has(outputs[0], "data") ) {
-              let notebook_metadata = notebook.model.metadata
+            _.forEach(outputs, function(output) {
+              console.log(output)
+              if ( _.size(output) > 0  && _.has(output, "data") ) {
+                let notebook_metadata = notebook.model.metadata
 
-              const results: string = _.get(_.get(outputs[0], "data"), "text/plain")
-              const parsed_results = results.substr(1, results.length - 2)
-              let jsonObject: {} = JSON.parse(parsed_results);
-              const requirements: Requirements = _.get(jsonObject, "resolution_engine")
-              const force: boolean = _.get(jsonObject, "force")
+                const results: string = _.get(_.get(output, "data"), "text/plain")
+                const parsed_results = results.substr(1, results.length - 2)
+                console.log(parsed_results)
+                let jsonObject: {} = JSON.parse(parsed_results);
+                const requirements: Requirements = _.get(jsonObject, "requirements")
+                const force: boolean = _.get(jsonObject, "force")
 
-              if ( !notebook_metadata.has('requirements') || force == true) {
-                notebook_metadata.set('requirements', JSON.stringify(requirements))
+                if ( !notebook_metadata.has('requirements') || force == true) {
+                  notebook_metadata.set('requirements', JSON.stringify(requirements))
+                }
+                else {
+                  kernel.requestExecute({
+                    code: "print('requirements already exist in notebook metadata, use --force to overwrite them!')"
+                  })
+                }
               }
-              else {
-                kernel.requestExecute({
-                  code: "print('requirements already exist in notebook metadata, use --force to overwrite them!')"
-                })
-              }
-            }
-
+            })
           }
 
           // Handle horus convert calls
