@@ -12,11 +12,26 @@
 import { Requirements, RequirementsLock } from "./requirements";
 
 
+export interface StackInfo {
+    link: string,
+    message: string,
+    type: string
+}
+
+export interface Justification {
+    link: string,
+    message: string,
+    type: string
+}
+
 export interface Advise {
+    thoth_analysis_id: string,
     error: boolean,
     error_msg: string,
     requirements: Requirements,
-    requirement_lock: RequirementsLock
+    requirements_lock: RequirementsLock,
+    stack_info: Array<StackInfo>,
+    justifications: Array<Justification>
 }
 
 export interface PipenvResult {
@@ -32,12 +47,20 @@ export interface OperatingSystem {
     version: string,
 }
 
+export interface Hardware {
+    cpu_model?: number,
+    cpu_family?: number,
+    gpu_family?: string,
+}
+
 export interface RuntimeEnvironment {
     name: string,
     operating_system: OperatingSystem
     python_version: string,
     recommendation_type: string,
-    base_image: string,
+    base_image?: string,
+    labels?: string,
+    hardware?: Hardware
 }
 
 export interface ThothConfig {
